@@ -20,9 +20,9 @@
 
 #include "box_db_table_definition.h"
 #include <glom/frame_glom.h>
-#include <glom/libglom/glade_utils.h>
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
-#include "../../../config.h"
+#include <glom/glade_utils.h>
+#include <glom/utils_ui.h> //For bold_message()).
+#include <libglom/libglom_config.h>
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -33,8 +33,8 @@ Box_DB_Table_Definition::Box_DB_Table_Definition()
   init();
 }
 
-Box_DB_Table_Definition::Box_DB_Table_Definition(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
-: Box_DB_Table(cobject, refGlade)
+Box_DB_Table_Definition::Box_DB_Table_Definition(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
+: Box_DB_Table(cobject, builder)
 {
   init();
 }
@@ -43,7 +43,7 @@ void Box_DB_Table_Definition::init()
 {
   //m_strHint = _("Click [Edit] to edit the field definition in more detail.\nUse the Mode menu to see Data or perform a Find.");
 
-  Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "window_field_definition_edit");
+  Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "window_field_definition_edit");
   if(refXml)
     refXml->get_widget_derived("window_field_definition_edit", m_pDialog);
 
@@ -62,7 +62,7 @@ void Box_DB_Table_Definition::init()
   //Set Type choices:
 
   Field::type_map_type_names mapFieldTypes = Field::get_usable_type_names();
-  AddDel::type_vecStrings vecTypes;
+  AddDel::type_vec_strings vecTypes;
   for(Field::type_map_type_names ::iterator iter = mapFieldTypes.begin(); iter != mapFieldTypes.end();++iter)
   {
     const Glib::ustring& name = (*iter).second;
@@ -138,7 +138,7 @@ bool Box_DB_Table_Definition::fill_from_database()
 
     Field::type_map_type_names mapFieldTypes = Field::get_type_names_ui();
 
-    for(type_vecFields::iterator iter = m_vecFields.begin(); iter != m_vecFields.end(); iter++)
+    for(type_vec_fields::iterator iter = m_vecFields.begin(); iter != m_vecFields.end(); ++iter)
     {
       const sharedptr<const Field>& field = *iter;
 
@@ -189,11 +189,11 @@ void Box_DB_Table_Definition::on_adddel_add(const Gtk::TreeModel::iterator& row)
       // unnecessary extra stuff just to get the field added into the
       // document:
 
-      Document_Glom* pDoc = static_cast<Document_Glom*>(get_document());
+      Document* pDoc = static_cast<Document*>(get_document());
       if(pDoc)
       {
         std::cout << field->get_glom_type() << std::endl;
-        Document_Glom::type_vecFields vecFields = pDoc->get_table_fields(m_table_name);
+        Document::type_vec_fields vecFields = pDoc->get_table_fields(m_table_name);
         vecFields.push_back(field);
         pDoc->set_table_fields(m_table_name, vecFields);
       }
@@ -260,7 +260,7 @@ bool Box_DB_Table_Definition::check_field_change(const sharedptr<const Field>& f
     if(field_new->get_calculation() != field_old->get_calculation())
     {
       //TODO: Only show this when there are > 100 records?
-      Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Recalculation Required")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE);
+      Gtk::MessageDialog dialog(Utils::bold_message(_("Recalculation Required")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE);
       dialog.set_secondary_text(_("You have changed the calculation used by this field so Glom must recalculate the value in all records. If the table contains many records then this could take a long time."));
       if(parent_window)
         dialog.set_transient_for(*parent_window);
@@ -311,7 +311,7 @@ bool Box_DB_Table_Definition::check_field_change(const sharedptr<const Field>& f
     }
 
     //Ask the user to confirm this major change:
-    Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Change primary key")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE);
+    Gtk::MessageDialog dialog(Utils::bold_message(_("Change primary key")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE);
     dialog.set_secondary_text(_("Are you sure that you wish to set this field as the primary key, instead of the existing primary key?"));
     if(parent_window)
       dialog.set_transient_for(*parent_window);
@@ -341,7 +341,7 @@ bool Box_DB_Table_Definition::check_field_change(const sharedptr<const Field>& f
 void Box_DB_Table_Definition::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint /* col */)
 {
   //Get old field definition:
-  Document_Glom* pDoc = static_cast<Document_Glom*>(get_document());
+  Document* pDoc = static_cast<Document*>(get_document());
   if(pDoc)
   {
     const Glib::ustring strFieldNameBeingEdited = m_AddDel.get_value_key(row);
@@ -350,7 +350,7 @@ void Box_DB_Table_Definition::on_adddel_changed(const Gtk::TreeModel::iterator&
     m_Field_BeingEdited = constfield;
 
     //Get DB field info: (TODO: This might be unnecessary).
-    type_vecFields::const_iterator iterFind = std::find_if( m_vecFields.begin(), m_vecFields.end(), predicate_FieldHasName<Field>(strFieldNameBeingEdited) );
+    type_vec_fields::const_iterator iterFind = std::find_if( m_vecFields.begin(), m_vecFields.end(), predicate_FieldHasName<Field>(strFieldNameBeingEdited) );
     if(iterFind == m_vecFields.end()) //If it was not found:
       std::cerr << "Box_DB_Table_Definition::on_adddel_changed(): field not found: " << strFieldNameBeingEdited << std::endl;
     else
@@ -410,11 +410,11 @@ sharedptr<Field> Box_DB_Table_Definition::get_field_definition(const Gtk::TreeMo
   const Glib::ustring strFieldNameBeforeEdit = m_AddDel.get_value_key(row);
 
   //Glom field definition:
-  Document_Glom* pDoc = static_cast<Document_Glom*>(get_document());
+  Document* pDoc = static_cast<Document*>(get_document());
   if(pDoc)
   {
-    Document_Glom::type_vecFields vecFields= pDoc->get_table_fields(m_table_name);
-    Document_Glom::type_vecFields::iterator iterFind = std::find_if( vecFields.begin(), vecFields.end(), predicate_FieldHasName<Field>(strFieldNameBeforeEdit) );
+    Document::type_vec_fields vecFields= pDoc->get_table_fields(m_table_name);
+    Document::type_vec_fields::iterator iterFind = std::find_if( vecFields.begin(), vecFields.end(), predicate_FieldHasName<Field>(strFieldNameBeforeEdit) );
 
     if((iterFind != vecFields.end()) && (*iterFind)) //If it was found:
     {
@@ -498,7 +498,7 @@ void Box_DB_Table_Definition::on_Properties_apply()
 
 sharedptr<Field> Box_DB_Table_Definition::change_definition(const sharedptr<const Field>& fieldOld, const sharedptr<const Field>& field)
 {
-  Bakery::BusyCursor busy_cursor(get_app_window());
+  BusyCursor busy_cursor(get_app_window());
 
   //DB field definition:
 
@@ -507,8 +507,8 @@ sharedptr<Field> Box_DB_Table_Definition::change_definition(const sharedptr<cons
   if(!fieldOld || !field)
     return result;
 
-  type_vecConstFields old_fields;
-  type_vecFields new_fields;
+  type_vec_const_fields old_fields;
+  type_vec_fields new_fields;
 
   if(fieldOld->get_primary_key() != field->get_primary_key())
   {
@@ -530,7 +530,7 @@ sharedptr<Field> Box_DB_Table_Definition::change_definition(const sharedptr<cons
 
     //Forget the remembered currently-viewed primary key value, 
     //because it will be useless with a different field as the primary key, or with no field as primary key:
-    Document_Glom* document = get_document();
+    Document* document = get_document();
     document->forget_layout_record_viewed(m_table_name);
   }
 
@@ -558,21 +558,21 @@ sharedptr<Field> Box_DB_Table_Definition::change_definition(const sharedptr<cons
   }
 
   //Extra Glom field definitions:
-  Document_Glom* pDoc = static_cast<Document_Glom*>(get_document());
+  Document* pDoc = static_cast<Document*>(get_document());
   if(pDoc)
   {
     //Get Table's fields:
-    Document_Glom::type_vecFields vecFields = pDoc->get_table_fields(m_table_name);
+    Document::type_vec_fields vecFields = pDoc->get_table_fields(m_table_name);
 
     for(unsigned int i = 0; i < old_fields.size(); ++ i)
     {
       //Find old field:
       const Glib::ustring field_name_old = old_fields[i]->get_name();
-      Document_Glom::type_vecFields::iterator iterFind = std::find_if( vecFields.begin(), vecFields.end(), predicate_FieldHasName<Field>(field_name_old) );
+      Document::type_vec_fields::iterator iterFind = std::find_if( vecFields.begin(), vecFields.end(), predicate_FieldHasName<Field>(field_name_old) );
       if(iterFind != vecFields.end()) //If it was found:
       {
         //Change it to the new Fields's value:
-	*iterFind = glom_sharedptr_clone(new_fields[i]);
+        *iterFind = glom_sharedptr_clone(new_fields[i]);
       }
       else
       {
@@ -623,24 +623,28 @@ void Box_DB_Table_Definition::fill_fields()
 
 bool Box_DB_Table_Definition::field_has_null_values(const sharedptr<const Field>& field)
 {
+  //TODO: Use SQL paramters?
   //Note that "= Null" doesn't work, though it doesn't error either.
   //Note also that SELECT COUNT always returns 0 if all the values are NULL, so we can't use that to be more efficient.
-  const Glib::ustring sql_query = "SELECT \"" + field->get_name() + "\" FROM \"" + m_table_name + "\" WHERE \"" + m_table_name + "\".\"" + field->get_name() + "\" IS NULL ";
+  const Glib::ustring sql_query = "SELECT \"" + field->get_name() + "\" FROM \"" + m_table_name + "\" WHERE \"" + m_table_name + "\".\"" + field->get_name() + "\" IS NULL LIMIT 1";
   //std::cout << "sql_query: " << sql_query << std::endl;
 
   long null_count = 0;
   Glib::RefPtr<Gnome::Gda::DataModel> datamodel = query_execute_select(sql_query);
-  if(datamodel && datamodel->get_n_rows() && datamodel->get_n_columns())
+  if(datamodel)
   {
-    null_count = datamodel->get_n_rows();
-    //std::cout << "debug: null_count = " << null_count << std::endl;
+    if(datamodel->get_n_rows() && datamodel->get_n_columns())
+    {
+      null_count = datamodel->get_n_rows();
+      //std::cout << "debug: null_count = " << null_count << std::endl;
+    }
   }
   else
   {
-    g_warning("Box_DB_Table_Definition::field_has_null_values(): SELECT COUNT() failed.");
+    std::cerr << "Box_DB_Table_Definition::field_has_null_values(): query failed: " << sql_query << std::endl;
   }
 
-   return null_count > 0; 
+  return null_count > 0; 
 }
 
 bool Box_DB_Table_Definition::field_has_non_unique_values(const sharedptr<const Field>& field)
@@ -655,7 +659,7 @@ bool Box_DB_Table_Definition::field_has_non_unique_values(const sharedptr<const
   if(datamodel)
   {
     count_distinct = datamodel->get_n_rows();
-    //std::cout << "debug: null_count = " << null_count << std::endl;
+    //std::cout << "debug: count_distinct = " << count_distinct << std::endl;
   }
   else
   {
